Usage
=====

``oncvpsp-tools`` implements the contents of ``oncvpsp.x`` input and output files as Python dataclasses. These are
documented below

.. autoclass:: oncvpsp_tools.input.ONCVPSPInput
    :members:

.. autoclass:: oncvpsp_tools.output.ONCVPSPOutput
    :members:
